const { MessageMedia } = require('whatsapp-web.js');
const config = require('../config.json');
const dotenv = require('dotenv');

dotenv.config();

const AUTHORIZED_NUMBER = process.env.AUTHORIZED_NUMBER;

/**
 * Enviar un recordatorio de actividad diaria al número autorizado.
 * @param {Object} client - Instancia del cliente de WhatsApp.
 * @param {String} actividad - Nombre de la actividad.
 * @param {String} mensaje - Mensaje personalizado para la actividad.
 */
const sendReminder = async (client, actividad, mensaje) => {
    const formattedMessage = `🔔 Recordatorio: ${actividad}\n📝 ${mensaje}`;

    try {
        await client.sendMessage(AUTHORIZED_NUMBER, formattedMessage);
        console.log(`📤 Recordatorio de ${actividad} enviado a ${AUTHORIZED_NUMBER}`);
    } catch (error) {
        console.error(`❌ Error al enviar recordatorio de ${actividad}:`, error);
    }
};

module.exports = {
    sendReminder
};